import * as cdk from 'aws-cdk-lib';
import { AuthenticationStack } from '../lib/authentication_stack';
import { StorageStack } from '../lib/storage_stack';
import { LambdaStack } from '../lib/lambda_stack';
import { ApiGatewayStack } from '../lib/apigateway_stack';
//import { FrontendStack } from '../lib/frontend_stack';

const app = new cdk.App();

// Common environment configuration
const env = {
  account: process.env.CDK_DEFAULT_ACCOUNT,
  region: process.env.CDK_DEFAULT_REGION,
};

//Adding Tags for better overview of costs
cdk.Tags.of(app).add('Environment', 'Production');
cdk.Tags.of(app).add('Project', 'ContactsApp');

const authStack = new AuthenticationStack(
  app,
  'ContactApp-AuthenticationStack',
  { env }
);
const storageStack = new StorageStack(app, 'ContactApp-StorageStack', {
  env,
});

const lambdaStack = new LambdaStack(app, 'ContactApp-LambdaStack', {
  contactsTable: storageStack.contactsTable,
  contactsBucket: storageStack.contactsBucket,
  cloudfrontImagesDistribution: storageStack.cloudfrontImagesDistribution,
  env,
});

new ApiGatewayStack(app, 'ContactApp-ApiGatewayStack', {
  userPool: authStack.userPool,
  createContactFunction: lambdaStack.createContactFunction,
  updateContactFunction: lambdaStack.updateContactFunction,
  deleteContactFunction: lambdaStack.deleteContactFunction,
  getContactFunction: lambdaStack.getContactFunction,
  env,
});

/* new FrontendStack(app, 'ContactApp-FrontendStack', {
  env,
}); */
