import { DynamoDB } from 'aws-sdk';
import { withCors } from '../../utils/addingCors';

const dynamoDb = new DynamoDB.DocumentClient();
const tableName = process.env.TABLE_NAME;

export const handler = async (event: any) => {
  // Extract userId from the claims
  const userId = event.requestContext.authorizer.claims.sub;
  if (!userId) {
    return withCors(403, { error: 'User not authenticated' });
  }

  const contactId = event.pathParameters?.contactId;

  try {
    if (contactId) {
      // Fetch specific contact
      const result = await dynamoDb
        .get({
          TableName: tableName!,
          Key: {
            userId: userId, // Add the partition key
            id: contactId, // Add the sort key
          },
        })
        .promise();

      if (!result.Item) {
        return withCors(404, { error: 'Contact not found' });
      }

      // Check ownership of the contact
      if (result.Item.userId !== userId) {
        return withCors(403, {
          error: 'You do not have permission to view this contact',
        });
      }

      return withCors(200, result.Item);
    } else {
      // Fetch all contacts for the authenticated user
      const result = await dynamoDb
        .query({
          TableName: tableName!,
          IndexName: 'userId-index', // Ensure you have a GSI on the `userId` attribute
          KeyConditionExpression: 'userId = :userId',
          ExpressionAttributeValues: {
            ':userId': userId,
          },
        })
        .promise();

      return withCors(200, result.Items || []);
    }
  } catch (error) {
    console.error('Error fetching contacts:', error);
    return withCors(500, { error: 'Could not fetch contacts' });
  }
};
