import { useState } from 'react';
import { CognitoUser, CognitoUserPool } from 'amazon-cognito-identity-js';
import { Button, TextField, Stack, Typography } from '@mui/material';
import { poolData } from 'constants/index';
import { useLocation, useNavigate } from 'react-router-dom';

const userPool = new CognitoUserPool(poolData);

export default function ResetPasswordPage() {
  const location = useLocation();
  const navigate = useNavigate();

  const { email, userAttributes } = location.state || {};
  const [newPassword, setNewPassword] = useState('');
  const [message, setMessage] = useState('');

  const handleSetNewPassword = () => {
    if (!email || !userAttributes) {
      setMessage('Invalid request. Please try logging in again.');
      return;
    }

    const user = new CognitoUser({ Username: email, Pool: userPool });

    // Clean up user attributes (remove read-only attributes like email_verified)
    delete userAttributes.email_verified;
    delete userAttributes.phone_number_verified;

    user.completeNewPasswordChallenge(newPassword, userAttributes, {
      onSuccess: () => {
        setMessage('Password updated successfully. Redirecting to login...');
        setTimeout(() => navigate('/auth/login'), 3000);
      },
      onFailure: (err) => {
        setMessage(err.message || 'Failed to set new password.');
      },
    });
  };

  return (
    <Stack spacing={2}>
      <Typography variant='h4'>Set New Password</Typography>
      <TextField
        label='New Password'
        type='password'
        value={newPassword}
        onChange={(e) => setNewPassword(e.target.value)}
      />
      <Button variant='contained' onClick={handleSetNewPassword}>
        Submit
      </Button>
      {message && <Typography color='error'>{message}</Typography>}
    </Stack>
  );
}
