import { useState } from 'react';
import { Button, TextField, Stack, Typography } from '@mui/material';
import useResponsive from 'hooks/useResponsive';
import Logo from 'components/Logo';
import { signUp } from '../../authServices/signUp';
import { confirmSignUp } from 'authServices/confirmSignUp';

export default function SignUpPage() {
  const isMobile = useResponsive('down', 'sm');
  const [email, setEmail] = useState('');
  const [password, setPassword] = useState('');
  const [message, setMessage] = useState('');
  const [signUpPage, setSignUpPage] = useState(true);
  const [verificationCode, setVerificationCode] = useState('');
  const [isConfirmed, setIsConfirmed] = useState(false);

  const handleConfirmSignUp = async () => {
    try {
      await confirmSignUp(email, verificationCode);
      setIsConfirmed(true);
    } catch (error) {
      setMessage(`Confirmation failed: ${error}`);
    }
  };

  const handleSignUp = async () => {
    try {
      await signUp(email, password);
      setSignUpPage(false);
    } catch (error) {
      setMessage(`SignUp failed: ${error}`);
    }
  };

  return (
    <Stack
      sx={{ height: isMobile ? 'auto' : '100%', pt: isMobile ? 10 : 0 }}
      justifyContent='center'
      alignItems='center'
      maxWidth={500}
      mx='auto'
      gap={2}
    >
      <Stack alignItems='center'>
        <Logo sx={{ width: 100, height: 100 }} />
        <Typography variant='h1'>Contacts App</Typography>
      </Stack>
      {signUpPage ? (
        <>
          <Typography variant='h4'>Sign Up</Typography>
          <TextField
            label='Email'
            value={email}
            onChange={(e) => setEmail(e.target.value)}
          />
          <TextField
            label='Password'
            type='password'
            value={password}
            onChange={(e) => setPassword(e.target.value)}
          />
          <Button variant='contained' onClick={handleSignUp}>
            SignUp
          </Button>
          {message && <Typography color='error'>{message}</Typography>}
        </>
      ) : (
        <>
          <Typography variant='h4'>Enter Verification Code</Typography>
          <TextField
            label='verification Code'
            type='text'
            value={verificationCode}
            onChange={(e: any) => setVerificationCode(e.target.value)}
          />
          <Button variant='contained' onClick={handleConfirmSignUp}>
            Confirm SignUp
          </Button>
          {isConfirmed && (
            <Typography color='error'>
              Your account has been confirmed!
            </Typography>
          )}
        </>
      )}
    </Stack>
  );
}
