import { createApi, fetchBaseQuery } from '@reduxjs/toolkit/query/react';
import { baseURL, resourcePath } from 'constants/index';

export const apiSlice = createApi({
  reducerPath: 'api',
  tagTypes: ['Contact', 'Label'],
  baseQuery: fetchBaseQuery({
    baseUrl: baseURL,
    prepareHeaders: (headers, { getState }) => {
      const token = (getState() as any).auth.tokens.idToken;
      if (token) {
        headers.set('Authorization', `Bearer ${token}`);
      }
      return headers;
    },
  }),
  endpoints: (builder) => ({
    getContacts: builder.query({
      query: () => `/${resourcePath}`,
      providesTags: ['Contact'],
    }),
    getContactById: builder.query({
      query: (id) => `/${resourcePath}/${id}`,
      providesTags: ['Contact'],
    }),
    createContact: builder.mutation({
      query: (contact) => ({
        url: `/${resourcePath}`,
        method: 'POST',
        body: contact,
      }),
      invalidatesTags: ['Contact'],
    }),
    updateContact: builder.mutation({
      query: ({ id, ...updatedContact }) => ({
        url: `/${resourcePath}/${id}`,
        method: 'PUT',
        body: updatedContact,
      }),
      invalidatesTags: ['Contact'],
    }),
    deleteContact: builder.mutation({
      query: (id) => ({
        url: `/${resourcePath}/${id}`,
        method: 'DELETE',
      }),
      invalidatesTags: ['Contact'],
    }),
  }),
});
export const {
  useGetContactsQuery,
  useGetContactByIdQuery,
  useCreateContactMutation,
  useUpdateContactMutation,
  useDeleteContactMutation,
} = apiSlice;
